@@ -1,19 +1,3 @@
- # Copyright (C) 2011, 2010, 2009 Oscar Perpiñán Lamigueiro
- #
- # This program is free software; you can redistribute it and/or
- # modify it under the terms of the GNU General Public License
- # as published by the Free Software Foundation; either version 2
- # of the License, or (at your option) any later version.
- #
- # This program is distributed in the hope that it will be useful,
- # but WITHOUT ANY WARRANTY; without even the implied warranty of
- # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- # GNU General Public License for more details.
- #
- # You should have received a copy of the GNU General Public License
- # along with this program; if not, write to the Free Software
- # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
- #/
 fProd<-function(inclin, 
                 module=list(), 
                 generator=list(), 
@@ -150,9 +134,10 @@ fProd<-function(inclin,
       result=(-B+sqrt(B^2-4*A*C))/(2*A)
     })
   }
-  
-  is.na(PacN) <- (PacN<0)
-  EffI=PacN/PdcN
+  EffI <- PacN/PdcN
+  pacNeg <- PacN <= 0
+  PacN[pacNeg] <- PdcN[pacNeg] <- EffI[pacNeg] <- 0
+
 	
 ###Potencia AC y DC sin la normalización
   Pac=with(inverter,PacN*Pinv*(Gef>Gumb)*(1-effSys$OhmAC/100)*(1-effSys$TrafoMT/100)*(1-effSys$Disp/100))
